/*
 * Copyright 2020 Fluence Labs Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

mod errors;
mod prepare;
mod version_checker;

pub(crate) use errors::HeapBaseError;
pub(crate) use errors::PrepareError;
pub(crate) use prepare::prepare_module;
pub(crate) use version_checker::check_sdk_version;
pub(crate) use version_checker::check_it_version;

pub(self) type PrepareResult<T> = std::result::Result<T, PrepareError>;
